CompleteArchive class
from: com.milibris.foundation.CompleteArchive
Constructors
- CompleteArchive(FoundationContext foundationContext, JObject? fileInputStream)
-
from:
public void <init>(com.milibris.foundation.FoundationContext foundationContext, java.io.FileInputStream fileInputStream)The returned object must be released after use, by calling thereleasemethod.factory - CompleteArchive.new$1(FoundationContext? foundationContext, JObject? uri)
-
from:
public void <init>(com.milibris.foundation.FoundationContext foundationContext, android.net.Uri uri)The returned object must be released after use, by calling thereleasemethod.factory - CompleteArchive.new$2(FoundationContext? foundationContext, JObject? file)
-
from:
public void <init>(com.milibris.foundation.FoundationContext foundationContext, java.io.File file)The returned object must be released after use, by calling thereleasemethod.factory - CompleteArchive.new$3(FoundationContext? foundationContext, JString? string)
-
from:
public void <init>(com.milibris.foundation.FoundationContext foundationContext, java.lang.String string)The returned object must be released after use, by calling thereleasemethod.factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- isReleased → bool
-
no setterinherited
- jClass → JClass
-
Returns
JClasscorresponding to concrete class of this object.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
as<
T extends JObject?> (JObjType< T> type, {bool releaseOriginal = false}) → T -
Casts this object to another
type.inherited -
isA<
T extends JObject?> (JObjType< T> type) → bool -
Whether this object is of the given
typeignoring the type parameters.inherited -
isInstanceOf(
JClass jclass) → bool -
Whether this object is of the type of the given
jclass.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
release(
) → void -
Releases the underlying
reference.inherited -
releasedBy(
Arena arena) → void -
Registers this object to be released at the end of
arena's lifetime.inherited -
toString(
) → String -
A string representation of this object.
inherited
-
unpackTo(
JObject? file) → JObject? -
from:
public com.milibris.foundation.Release unpackTo(java.io.File file)The returned object must be released after use, by calling thereleasemethod. -
unpackTo$1(
JString? string) → JObject? -
from:
public com.milibris.foundation.Release unpackTo(java.lang.String string)The returned object must be released after use, by calling thereleasemethod. -
unpackTo$2(
JObject uri) → JObject? -
from:
public com.milibris.foundation.Release unpackTo(android.net.Uri uri)The returned object must be released after use, by calling thereleasemethod.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- nullableType → const $CompleteArchive$NullableType
- The type which includes information such as the signature of this class.
- type → const $CompleteArchive$Type