OneReaderActivity$Companion class

from: com.milibris.onereader.feature.OneReaderActivity$Companion

Constructors

OneReaderActivity$Companion(JObject? defaultConstructorMarker)
from: synthetic public void <init>(kotlin.jvm.internal.DefaultConstructorMarker defaultConstructorMarker) The returned object must be released after use, by calling the release method.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
isReleased bool
no setterinherited
jClass → JClass
Returns JClass corresponding to concrete class of this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

as<T extends JObject?>(JObjType<T> type, {bool releaseOriginal = false}) → T
Casts this object to another type.
inherited
isA<T extends JObject?>(JObjType<T> type) bool
Whether this object is of the given type ignoring the type parameters.
inherited
isInstanceOf(JClass jclass) bool
Whether this object is of the type of the given jclass.
inherited
newIntent(JObject context, ReaderSettings readerSettings, JObject productRepository, JObject? readerListener, JObject? pageAdRepository, JObject? searchProvider, JString? string, JFloat? float) → JObject
from: public final android.content.Intent newIntent(android.content.Context context, com.milibris.onereader.data.session.ReaderSettings readerSettings, com.milibris.onereader.repository.ProductRepository productRepository, com.milibris.onereader.data.session.ReaderListener readerListener, com.milibris.onereader.repository.PageAdRepository pageAdRepository, com.milibris.onereader.feature.search.SearchProvider searchProvider, java.lang.String string, java.lang.Float float) The returned object must be released after use, by calling the release method.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
Releases the underlying reference.
inherited
releasedBy(Arena arena) → void
Registers this object to be released at the end of arena's lifetime.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

nullableType → const $OneReaderActivity$Companion$NullableType
The type which includes information such as the signature of this class.
type → const $OneReaderActivity$Companion$Type