XmlPdfReaderDataSource class

from: com.milibris.reader.XmlPdfReaderDataSource

Constructors

XmlPdfReaderDataSource(ReaderSettings readerSettings)
from: public void <init>(com.milibris.onereader.data.session.ReaderSettings readerSettings) The returned object must be released after use, by calling the release method.
factory

Properties

context ↔ JObject
from: public android.content.Context context The returned object must be released after use, by calling the release method.
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
isReleased bool
no setterinherited
jClass → JClass
Returns JClass corresponding to concrete class of this object.
no setterinherited
materialParser ↔ JObject
from: public com.milibris.reader.XmlPdfMaterialParser materialParser The returned object must be released after use, by calling the release method.
getter/setter pair
product ↔ JObject
from: public com.milibris.foundation.Product product The returned object must be released after use, by calling the release method.
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

as<T extends JObject?>(JObjType<T> type, {bool releaseOriginal = false}) → T
Casts this object to another type.
inherited
getAllArticles(JObject function1, JObject function11) → void
from: public void getAllArticles(kotlin.jvm.functions.Function1<? super java.util.List, kotlin.Unit> function1, kotlin.jvm.functions.Function1<? super com.milibris.onereader.data.error.ReaderError, kotlin.Unit> function11)
getArticle(JString string) → JObject?
from: public com.milibris.onereader.data.article.IArticle getArticle(java.lang.String string) The returned object must be released after use, by calling the release method.
getBoxes(int i, JObject function2, JObject function1) → void
from: public void getBoxes(int i, kotlin.jvm.functions.Function2<? super java.util.List, ? super java.lang.Integer, kotlin.Unit> function2, kotlin.jvm.functions.Function1<? super com.milibris.onereader.data.error.ReaderError, kotlin.Unit> function1)
getIssueID() → JString?
from: public java.lang.String getIssueID() The returned object must be released after use, by calling the release method.
getMaterialParser() → JObject
from: public final com.milibris.reader.XmlPdfMaterialParser getMaterialParser() The returned object must be released after use, by calling the release method.
getMilibrisArticle(JString string) → JObject?
from: public final com.milibris.reader.summary.Article getMilibrisArticle(java.lang.String string) The returned object must be released after use, by calling the release method.
getMilibrisArticle$1(JObject iArticle) → JObject?
from: public final com.milibris.reader.summary.Article getMilibrisArticle(com.milibris.onereader.data.article.IArticle iArticle) The returned object must be released after use, by calling the release method.
getMode() → JObject
from: public com.milibris.onereader.repository.ProductRepository$ReleaseMode getMode() The returned object must be released after use, by calling the release method.
getProduct() → JObject
from: public final com.milibris.foundation.Product getProduct() The returned object must be released after use, by calling the release method.
getProduct$1(JObject function1, JObject function11) → void
from: public void getProduct(kotlin.jvm.functions.Function1<? super com.milibris.onereader.data.product.Product, kotlin.Unit> function1, kotlin.jvm.functions.Function1<? super com.milibris.onereader.data.error.ReaderError, kotlin.Unit> function11)
getReaderSettings() ReaderSettings
from: public final com.milibris.onereader.data.session.ReaderSettings getReaderSettings() The returned object must be released after use, by calling the release method.
getResourceLDUri(int i, JObject function1, JObject function11) → void
from: public void getResourceLDUri(int i, kotlin.jvm.functions.Function1<? super android.net.Uri, kotlin.Unit> function1, kotlin.jvm.functions.Function1<? super com.milibris.onereader.data.error.ReaderError, kotlin.Unit> function11)
getResourcePDF(int i, JObject function2, JObject function1) → void
from: public void getResourcePDF(int i, kotlin.jvm.functions.Function2<? super java.io.InputStream, ? super java.lang.Integer, kotlin.Unit> function2, kotlin.jvm.functions.Function1<? super com.milibris.onereader.data.error.ReaderError, kotlin.Unit> function1)
getResourcePDFFileName(int i) → JString
from: public java.lang.String getResourcePDFFileName(int i) The returned object must be released after use, by calling the release method.
getResourceThumbnailUri(int i, JObject function1, JObject function11) → void
from: public void getResourceThumbnailUri(int i, kotlin.jvm.functions.Function1<? super android.net.Uri, kotlin.Unit> function1, kotlin.jvm.functions.Function1<? super com.milibris.onereader.data.error.ReaderError, kotlin.Unit> function11)
init(JObject context, JString string) → void
from: public final void init(android.content.Context context, java.lang.String string)
isA<T extends JObject?>(JObjType<T> type) bool
Whether this object is of the given type ignoring the type parameters.
inherited
isInstanceOf(JClass jclass) bool
Whether this object is of the type of the given jclass.
inherited
isSinglePDF() bool
from: public boolean isSinglePDF()
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
release() → void
Releases the underlying reference.
inherited
releasedBy(Arena arena) → void
Registers this object to be released at the end of arena's lifetime.
inherited
setMaterialParser(JObject xmlPdfMaterialParser) → void
from: public final void setMaterialParser(com.milibris.reader.XmlPdfMaterialParser xmlPdfMaterialParser)
setProduct(JObject product) → void
from: public final void setProduct(com.milibris.foundation.Product product)
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

Companion XmlPdfReaderDataSource$Companion
from: static public final com.milibris.reader.XmlPdfReaderDataSource$Companion Companion The returned object must be released after use, by calling the release method.
no setter

Constants

nullableType → const $XmlPdfReaderDataSource$NullableType
The type which includes information such as the signature of this class.
type → const $XmlPdfReaderDataSource$Type