OneReaderActivity class
from: com.milibris.onereader.feature.OneReaderActivity
Constructors
- OneReaderActivity()
-
from:
public void <init>()The returned object must be released after use, by calling thereleasemethod.factory
Properties
- binding ↔ JObject
-
from:
public com.milibris.onereader.databinding.OneReaderActivityBinding bindingThe returned object must be released after use, by calling thereleasemethod.getter/setter pair - hashCode → int
-
The hash code for this object.
no setterinherited
- isReleased → bool
-
no setterinherited
- jClass → JClass
-
Returns
JClasscorresponding to concrete class of this object.no setterinherited - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
as<
T extends JObject?> (JObjType< T> type, {bool releaseOriginal = false}) → T -
Casts this object to another
type.inherited -
getBinding(
) → JObject -
from:
public final com.milibris.onereader.databinding.OneReaderActivityBinding getBinding()The returned object must be released after use, by calling thereleasemethod. -
getResultLauncher(
) → JObject -
from:
public final androidx.activity.result.ActivityResultLauncher<android.content.Intent> getResultLauncher()The returned object must be released after use, by calling thereleasemethod. -
isA<
T extends JObject?> (JObjType< T> type) → bool -
Whether this object is of the given
typeignoring the type parameters.inherited -
isInstanceOf(
JClass jclass) → bool -
Whether this object is of the type of the given
jclass.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onBackPressed(
) → void -
from:
public void onBackPressed() -
release(
) → void -
Releases the underlying
reference.inherited -
releasedBy(
Arena arena) → void -
Registers this object to be released at the end of
arena's lifetime.inherited -
setBinding(
JObject oneReaderActivityBinding) → void -
from:
public final void setBinding(com.milibris.onereader.databinding.OneReaderActivityBinding oneReaderActivityBinding) -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- ARTICLE_INDEX → JString
-
from:
static public final java.lang.String ARTICLE_INDEXThe returned object must be released after use, by calling thereleasemethod.no setter - Companion → OneReaderActivity$Companion
-
from:
static public final com.milibris.onereader.feature.OneReaderActivity$Companion CompanionThe returned object must be released after use, by calling thereleasemethod.no setter - READER_SHARED_IMAGE_RATIO → JString
-
from:
static public final java.lang.String READER_SHARED_IMAGE_RATIOThe returned object must be released after use, by calling thereleasemethod.no setter - READER_SHARED_IMAGE_URL_KEY → JString
-
from:
static public final java.lang.String READER_SHARED_IMAGE_URL_KEYThe returned object must be released after use, by calling thereleasemethod.no setter - SHARED_ELEMENT_TRANSITION_NAME → JString
-
from:
static public final java.lang.String SHARED_ELEMENT_TRANSITION_NAMEThe returned object must be released after use, by calling thereleasemethod.no setter
Static Methods
-
newIntent(
JObject context, ReaderSettings readerSettings, JObject productRepository, JObject? readerListener, JObject? pageAdRepository, JObject? searchProvider, JString? string, JFloat? float) → JObject -
from:
static public final android.content.Intent newIntent(android.content.Context context, com.milibris.onereader.data.session.ReaderSettings readerSettings, com.milibris.onereader.repository.ProductRepository productRepository, com.milibris.onereader.data.session.ReaderListener readerListener, com.milibris.onereader.repository.PageAdRepository pageAdRepository, com.milibris.onereader.feature.search.SearchProvider searchProvider, java.lang.String string, java.lang.Float float)The returned object must be released after use, by calling thereleasemethod.
Constants
- nullableType → const $OneReaderActivity$NullableType
- The type which includes information such as the signature of this class.
- type → const $OneReaderActivity$Type