context property
JObject
get
context
from: public android.content.Context context
The returned object must be released after use, by calling the release method.
Implementation
jni$_.JObject get context => _id_context.get(this, const jni$_.JObjectType());
set
context
(JObject value)
from: public android.content.Context context
The returned object must be released after use, by calling the release method.
Implementation
set context(jni$_.JObject value) =>
_id_context.set(this, const jni$_.JObjectType(), value);